@@ -294,8 +294,8 @@ def sync_folder(src_parent_path, dst_path,
                 sub_folder = os.path.join(folder, file)
                 if os.path.isdir(sub_folder):
                     remove_empty_dirs(sub_folder)
-
-            if len(os.listdir(folder)) == 0:
+            # can't remove symlink folder
+            if len(os.listdir(folder)) == 0 and not os.path.islink(folder):
                 os.rmdir(folder)
 
     if src_parent_path is None or not os.path.isdir(src_parent_path) or dst_path is None or files_to_sync is None:
@@ -305,8 +305,8 @@ def sync_folder(src_parent_path, dst_path,
     dst_path = os.path.realpath(dst_path)
     previous_cwd = os.getcwd()
     os.chdir(src_parent_path)
-    # 清理相对目录不对的文件
-    abs_src_pathes = [os.path.realpath(file) for file in files_to_sync if os.path.realpath(file).startswith(src_parent_path)]
+    # 清理相对目录不对的文件 （此处默认了不区分大小写的文件系统）
+    abs_src_pathes = [os.path.realpath(file) for file in files_to_sync if os.path.realpath(file).lower().startswith(src_parent_path.lower())]
     os.chdir(previous_cwd)
     # 清理不存在的文件
     abs_src_pathes = [path for path in abs_src_pathes if os.path.exists(path)]
